@@ -13,28 +13,15 @@ use MarpaX::Languages::C::AST::Util::Data::Find;
 use File::Basename qw/basename dirname/;
 use Scalar::Util qw/blessed/;
 use Data::Dumper;
-
-autoflush STDOUT 1;
-
 use Log::Log4perl qw/:easy/;
 use Log::Any::Adapter;
 use Log::Any qw/$log/;
-#
-# Init log
-#
-our $defaultLog4perlConf = <<DEFAULT_LOG4PERL_CONF;
-log4perl.rootLogger              = WARN, Screen
-log4perl.appender.Screen         = Log::Log4perl::Appender::Screen
-log4perl.appender.Screen.stderr  = 0
-log4perl.appender.Screen.layout  = PatternLayout
-log4perl.appender.Screen.layout.ConversionPattern = %d %-5p %6P %m{chomp}%n
-DEFAULT_LOG4PERL_CONF
-Log::Log4perl::init(\$defaultLog4perlConf);
-Log::Any::Adapter->set('Log4perl');
+
+autoflush STDOUT 1;
 
 # ABSTRACT: C source analysis
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 # PODNAME: c2ast.pl
 
@@ -48,6 +35,7 @@ my @lexeme = ();
 my $progress = 0;
 my @check = ();
 my $dump = 0;
+my $loglevel = 'WARN';
 
 if (! GetOptions ('help!' => \$help,
                   'cpp=s' => \@cpp,
@@ -58,10 +46,25 @@ if (! GetOptions ('help!' => \$help,
                   'lexeme=s' => \@lexeme,
                   'progress!' => \$progress,
 		  'check=s' => \@check,
-		  'dump!' => \$dump)) {
+		  'dump!' => \$dump,
+		  'loglevel=s' => \$loglevel,
+		  )) {
   usage(EXIT_FAILURE);
 }
 
+# ----
+# Init 
+# ----
+my $defaultLog4perlConf = <<DEFAULT_LOG4PERL_CONF;
+log4perl.rootLogger              = $loglevel, Screen
+log4perl.appender.Screen         = Log::Log4perl::Appender::Screen
+log4perl.appender.Screen.stderr  = 0
+log4perl.appender.Screen.layout  = PatternLayout
+log4perl.appender.Screen.layout.ConversionPattern = %d %-5p %6P %m{chomp}%n
+DEFAULT_LOG4PERL_CONF
+Log::Log4perl::init(\$defaultLog4perlConf);
+Log::Any::Adapter->set('Log4perl');
+
 @cpp = ('cpp') if (! @cpp);
 
 if ($help || ! @ARGV) {
@@ -101,7 +104,7 @@ if ($progress) {
 # Parse C
 # -------
 map {++$lexemeCallbackHash{lexeme}->{$_}} @lexeme;
-my $cAstObject = MarpaX::Languages::C::AST->new(lexemeCallback => [ \&lexemeCallback, \%lexemeCallbackHash ]);
+my $cAstObject = MarpaX::Languages::C::AST->new(lexemeCallback => [ \&lexemeCallback, \%lexemeCallbackHash ], logInfo => $log->is_info());
 my $bless = $cAstObject->parse(\$preprocessedOutput);
 if ($progress) {
     if ($lexemeCallbackHash{nbLines} > $lexemeCallbackHash{next_progress}) {
@@ -283,6 +286,7 @@ where options can be:
                      Any check that is not ok will print on STDERR.
 --dump               Dump parse tree value. Always happen eventually as the last post-processing.
                      Will print on STDOUT.
+--loglevel <level>   Log::log4perl MarpaX::Languages::C::AST level. <level> has to be something meaningful for Log::Log4perl, typically WARN, INFO, ERROR, etc. Please note that to trace Marpa library itself, ony the environment variable MARPA_TRACE can be used. So, for example, to have the maximum logging possible, you set MARPA_TRACE environment variable to a true value and --loglevel TRACE. Default value is WARN.
 Examples:
 
 Typical usages
@@ -313,7 +317,7 @@ c2ast.pl - C source analysis
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 AUTHOR
 
