@@ -6,7 +6,7 @@ use MarpaX::Languages::C::AST::Grammar::ISO_ANSI_C_2011::Actions;
 
 # ABSTRACT: ISO ANSI C 2011 grammar written in Marpa BNF
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 
 sub new {
@@ -64,7 +64,7 @@ MarpaX::Languages::C::AST::Grammar::ISO_ANSI_C_2011 - ISO ANSI C 2011 grammar wr
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -1772,30 +1772,25 @@ gccAsmStatement ::= gccAsmExpression SEMICOLON
 typeQualifierMaybe ::= typeQualifier
                      | gccEmptyRule
 
-gccAsmOperandList ::= gccAsmOperand
-                       | COMMA gccAsmOperandList
+gccAsmExpression ::= GCC_ASM typeQualifierMaybe LPAREN expression gccAsmInnerOperandListMaybe RPAREN
 
-gccAsmClobberList ::= gccAsmClobber
-                       | COMMA gccAsmClobber
+gccAsmClobberList ::= gccAsmClobber | gccAsmClobberList COMMA gccAsmClobber
 
-gccAsmClobberExpressionMaybe ::= gccAsmClobberExpression
-                               | gccEmptyRule
+gccAsmOperandList ::= gccAsmOperand | gccAsmOperandList COMMA gccAsmOperand
 
 gccAsmOperandListMaybe ::= gccAsmOperandList | gccEmptyRule
 
-gccAsmOperandExpression ::= COLON gccAsmOperandListMaybe
+gccAsmInnerClobberList ::= COLON gccAsmClobberList
 
-gccAsmClobberExpression ::= COLON gccAsmClobberList
+gccAsmInnerClobberListMaybe ::= gccAsmInnerClobberList | gccEmptyRule
 
-gccAsmOperandInnerExpression ::= gccAsmOperandExpression gccAsmClobberExpressionMaybe
+gccAsmInnerOperandList2 ::= COLON gccAsmOperandListMaybe gccAsmInnerClobberListMaybe
 
-gccAsmOperandInnerExpressionMaybe ::= gccAsmOperandInnerExpression
-                                    | gccEmptyRule
+gccAsmInnerOperandList2Maybe ::= gccAsmInnerOperandList2 | gccEmptyRule
 
-gccAsmInnerExpressionMaybe ::= gccAsmOperandExpression gccAsmOperandInnerExpressionMaybe
-                                 | gccEmptyRule
+gccAsmInnerOperandList ::= COLON gccAsmOperandListMaybe gccAsmInnerOperandList2Maybe
 
-gccAsmExpression ::= GCC_ASM typeQualifierMaybe LPAREN expression gccAsmInnerExpressionMaybe RPAREN
+gccAsmInnerOperandListMaybe ::= gccAsmInnerOperandList | gccEmptyRule
 
 gccAsmOperandPrefix ::= LBRACKET IDENTIFIER RBRACKET
 
